@@ -1,4 +1,4 @@
-#!/usr/bin/python2
+#!/usr/bin/python3
 #
 # Copyright 2011 Free Software Foundation, Inc.
 #
@@ -20,6 +20,8 @@
 # Boston, MA 02110-1301, USA.
 #
 
+from __future__ import division
+from __future__ import unicode_literals
 from gnuradio import gr
 from gnuradio import audio
 from gnuradio import blocks
@@ -33,7 +35,7 @@ def build_graph():
     enc = vocoder.alaw_encode_sb()
     dec = vocoder.alaw_decode_bs()
     s2f = blocks.short_to_float()
-    sink_scale = blocks.multiply_const_ff(1.0/32767.)
+    sink_scale = blocks.multiply_const_ff(1.0 / 32767.)
     sink = audio.sink(8000)
     tb.connect(src, src_scale, f2s, enc, dec, s2f, sink_scale, sink)
     return tb
@@ -41,6 +43,6 @@ def build_graph():
 if __name__ == '__main__':
     tb = build_graph()
     tb.start()
-    raw_input ('Press Enter to exit: ')
+    input ('Press Enter to exit: ')
     tb.stop()
     tb.wait()
